@@ -1,6 +1,6 @@
 package Perl6::Pod::To::XHTML::MakeBody;
 
-#$Id$
+#$Id: MakeBody.pm 587 2009-08-11 03:13:15Z zag $
 
 =pod
 
@@ -12,7 +12,7 @@ Perl6::Pod::To::XHTML::MakeBody - add body section
 
     use Perl6::Pod::To::XHTML::MakeBody;
     my $x         = '';
-    my $xml_writer = new XML::ExtOn::Writer:: Output => \$x;
+    my $xml_writer = new XML::SAX::Writer:: Output => \$x;
     my $body_filter = new Perl6::Pod::To::XHTML::MakeBody::;
     my $out_filter = create_pipe($body_filter,  $xml_writer);
     my $to_parser = new Perl6::Pod::To::XHTML::
@@ -41,32 +41,29 @@ sub on_start_element {
     my ( $self, $el ) = @_;
     return $el unless $self->{SKIP_ROOT}++;
     return $el if $self->{OK} or $self->{HEADMODE};
-
     #if start head set flag
-    if ( $el->local_name eq 'head' ) {
+    if ( $el->local_name eq 'head') {
         $self->{HEADMODE}++;
-    }
-    else {
-        my $start = $self->mk_start_element( $self->mk_element('body') );
+    } else {
+        my $start = $self->mk_start_element($self->mk_element('body'));
         $self->{OK}++;
-        return [ $start, $el ];
+        return [ $start, $el]
     }
     $el;
 }
-
 sub on_end_element {
-    my ( $self, $el ) = @_;
-    if ( $el->local_name eq 'head' ) {
+    my ($self, $el) = @_;
+    if ($el->local_name eq 'head' ) {
         delete $self->{HEADMODE};
     }
-    if ( $self->{OK} and my $current = $self->current_element ) {
-        my $cname = $current->local_name;
-        if ( $cname eq 'body' ) {
-            delete $self->{OK};    #clean check flag
-            return [ $self->mk_end_element( $self->current_element ), $el ];
-        }
-    }
     return $el;
 }
 
+sub end_document {
+    my $self = shift;
+    if ( $self->{OK} ) {
+        $self->_process_comm($self->mk_end_element( $self->mk_element('body')))
+    }
+    return $self->SUPER::end_document(@_);
+}
 1;
