@@ -1,10 +1,10 @@
 #===============================================================================
 #
-#  DESCRIPTION: test block =code
+#  DESCRIPTION: test block =code 
 #
 #       AUTHOR:  Aliaksandr P. Zahatski, <zahatski@gmail.com>
 #===============================================================================
-#$Id$
+#$Id: code.pm 585 2009-08-05 06:51:38Z zag $
 
 package T::Block::code;
 use strict;
@@ -15,9 +15,10 @@ use Perl6::Pod::To::XHTML;
 use XML::ExtOn('create_pipe');
 use base 'TBase';
 
+
 sub c01_explicit_implicit : Test {
     my $t = shift;
-    my $x = $t->parse_to_xml(<<T);
+    my $x = $t->parse_to_xml (<<T);
 =begin pod
 test para.test para.test.pas
 
@@ -29,80 +30,45 @@ some para
     this is a code
 =end pod
 T
-    $t->is_deeply_xml(
-        $x,
-q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'>test para.test para.test.pas
+   $t->is_deeply_xml( $x, q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'>test para.test para.test.pas
 </para><code pod:type='block'><![CDATA[  code block
 ]]></code><para pod:type='block'>some para
 </para><code pod:type='block'><![CDATA[    this is a code
-]]></code></pod>#
-    );
+]]></code></pod>#)
 }
 
+
 sub c02_deny_format_codes : Test {
     my $t = shift;
-    my $x = $t->parse_to_xml( <<T);
+    my $x = $t->parse_to_xml ( <<T);
 =begin pod
     test B<some>
 
 tets B<asdasd>
 =end pod
 T
-#    diag $x;exit;
-    $t->is_deeply_xml(
-        $x,
+    $t->is_deeply_xml( $x,
 q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><code pod:type='block'><![CDATA[    test B<some>
 ]]></code><para pod:type='block'>tets <B pod:type='code'>asdasd</B>
-</para></pod>#
-      )
+</para></pod>#)
 
 }
 
 sub c02_to_xhml : Test {
-    my $t        = shift;
-    my $x        = '';
+    my $t= shift;
+    my $x = '';
     my $to_xhtml = new Perl6::Pod::To::XHTML:: out_put => \$x;
-    my $p        = create_pipe( 'Perl6::Pod::Parser', $to_xhtml );
-    $p->parse( \<<TT);
+    my $p = create_pipe('Perl6::Pod::Parser', $to_xhtml);
+    $p->parse(\<<TT);
 =begin pod
 =code
     test code
 =end pod
 TT
-    $t->is_deeply_xml(
-        $x,
-        q# <html xmlns='http://www.w3.org/1999/xhtml'><pre><code>    test code
- </code></pre></html>#
-    );
-}
-
-sub c04_to_docbook : Test {
-    my $t = shift;
-    my $x = $t->parse_to_docbook( <<T );
-=begin pod
-=code
-    test code
-=end pod
-T
-    $t->is_deeply_xml(
-        $x,
-        q#<chapter><programlisting><![CDATA[    test code
- ]]></programlisting></chapter>#
-    );
-}
-
-sub c05_allow_in_code : Test(2) {
-    my $t = shift;
-    my $x = $t->parse_to_xhtml(<<T);
-=begin pod 
-=for code :allow<B>
-test B<para.test> para.test.I<pas>
-=end pod
-T
-    ok $x =~ m{<strong>para.test</strong>}, ':allow<B>';
-    ok $x =~ m{I&lt;pas&gt;}, 'deny format code';
-
+    $t->is_deeply_xml( $x, q# <html xmlns='http://www.w3.org/1999/xhtml'><pre><code>    test code
+ </code></pre></html># )
 }
 
 1;
 
+
